#[non_exhaustive]pub enum EndpointingSensitivity {
Unspecified,
Standard,
Supershort,
Short,
UnknownValue(UnknownValue),
}Expand description
Endpointing sensitivity is intended for applications that want to minimize result latency, possibly at the expense of quality. Some utterances may be broken up into multiple fragments.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
If no value is specified, the values for ENDPOINTING_SENSITIVITY_STANDARD will be used.
Standard
Standard sensitivity, no optimization for latency.
Supershort
Super short sensitivity, optimized for super short utterances like single words (“Yes”, “No”, “Hello”, etc.) or a single phrase, command or short query (e.g. “check balance”, “five dollars”, “call Mom”).
Short
Short sensitivity, optimized for short utterances like single sentences. (e.g. “Remind me to call the dentist tomorrow morning at nine”, “Navigate to the nearest coffee shop that is currently open”)
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using EndpointingSensitivity::value or EndpointingSensitivity::name.
Implementations