#[non_exhaustive]pub struct BatchRecognizeFileMetadata {
pub config: Option<RecognitionConfig>,
pub config_mask: Option<FieldMask>,
pub audio_source: Option<AudioSource>,
/* private fields */
}Expand description
Metadata about a single file in a batch for BatchRecognize.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.config: Option<RecognitionConfig>Features and audio metadata to use for the Automatic Speech Recognition. This field in combination with the config_mask field can be used to override parts of the default_recognition_config of the Recognizer resource as well as the config at the request level.
config_mask: Option<FieldMask>The list of fields in
config that
override the values in the
default_recognition_config
of the recognizer during this recognition request. If no mask is provided,
all non-default valued fields in
config override
the values in the recognizer for this recognition request. If a mask is
provided, only the fields listed in the mask override the config in the
recognizer for this recognition request. If a wildcard (*) is provided,
config
completely overrides and replaces the config in the recognizer for this
recognition request.
audio_source: Option<AudioSource>The audio source, which is a Google Cloud Storage URI.
Implementations
Sourceimpl BatchRecognizeFileMetadata
impl BatchRecognizeFileMetadata
Sourcepub fn set_config<T>(self, v: T) -> Selfwhere
T: Into<RecognitionConfig>,
pub fn set_config<T>(self, v: T) -> Selfwhere
T: Into<RecognitionConfig>,
Sourcepub fn set_or_clear_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<RecognitionConfig>,
pub fn set_or_clear_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<RecognitionConfig>,
Sets or clears the value of config.
Example
use google_cloud_speech_v2::model::RecognitionConfig;
let x = BatchRecognizeFileMetadata::new().set_or_clear_config(Some(RecognitionConfig::default()/* use setters */));
let x = BatchRecognizeFileMetadata::new().set_or_clear_config(None::<RecognitionConfig>);Sourcepub fn set_config_mask<T>(self, v: T) -> Self
pub fn set_config_mask<T>(self, v: T) -> Self
Sets the value of config_mask.
Example
use wkt::FieldMask;
let x = BatchRecognizeFileMetadata::new().set_config_mask(FieldMask::default()/* use setters */);Sourcepub fn set_or_clear_config_mask<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_config_mask<T>(self, v: Option<T>) -> Self
Sets or clears the value of config_mask.
Example
use wkt::FieldMask;
let x = BatchRecognizeFileMetadata::new().set_or_clear_config_mask(Some(FieldMask::default()/* use setters */));
let x = BatchRecognizeFileMetadata::new().set_or_clear_config_mask(None::<FieldMask>);Sourcepub fn set_audio_source<T: Into<Option<AudioSource>>>(self, v: T) -> Self
pub fn set_audio_source<T: Into<Option<AudioSource>>>(self, v: T) -> Self
Sets the value of audio_source.
Note that all the setters affecting audio_source are mutually
exclusive.
Example
use google_cloud_speech_v2::model::batch_recognize_file_metadata::AudioSource;
let x = BatchRecognizeFileMetadata::new().set_audio_source(Some(AudioSource::Uri("example".to_string())));Sourcepub fn uri(&self) -> Option<&String>
pub fn uri(&self) -> Option<&String>
The value of audio_source
if it holds a Uri, None if the field is not set or
holds a different branch.