#[non_exhaustive]pub struct BatchRecognizeRequest {
pub recognizer: String,
pub config: Option<RecognitionConfig>,
pub config_mask: Option<FieldMask>,
pub files: Vec<BatchRecognizeFileMetadata>,
pub recognition_output_config: Option<RecognitionOutputConfig>,
pub processing_strategy: ProcessingStrategy,
/* private fields */
}Expand description
Request message for the BatchRecognize method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.recognizer: StringRequired. The name of the Recognizer to use during recognition. The
expected format is
projects/{project}/locations/{location}/recognizers/{recognizer}. The
{recognizer} segment may be set to _ to use an empty implicit Recognizer.
config: Option<RecognitionConfig>Features and audio metadata to use for the Automatic Speech Recognition. This field in combination with the config_mask field can be used to override parts of the default_recognition_config of the Recognizer resource.
config_mask: Option<FieldMask>The list of fields in
config that override
the values in the
default_recognition_config
of the recognizer during this recognition request. If no mask is provided,
all given fields in
config override the
values in the recognizer for this recognition request. If a mask is
provided, only the fields listed in the mask override the config in the
recognizer for this recognition request. If a wildcard (*) is provided,
config completely
overrides and replaces the config in the recognizer for this recognition
request.
files: Vec<BatchRecognizeFileMetadata>Audio files with file metadata for ASR. The maximum number of files allowed to be specified is 15.
recognition_output_config: Option<RecognitionOutputConfig>Configuration options for where to output the transcripts of each file.
processing_strategy: ProcessingStrategyProcessing strategy to use for this request.
Implementations
Sourceimpl BatchRecognizeRequest
impl BatchRecognizeRequest
Sourcepub fn set_recognizer<T: Into<String>>(self, v: T) -> Self
pub fn set_recognizer<T: Into<String>>(self, v: T) -> Self
Sets the value of recognizer.
Example
let x = BatchRecognizeRequest::new().set_recognizer(format!("projects/{project_id}/locations/{location_id}/recognizers/{recognizer_id}"));Sourcepub fn set_config<T>(self, v: T) -> Selfwhere
T: Into<RecognitionConfig>,
pub fn set_config<T>(self, v: T) -> Selfwhere
T: Into<RecognitionConfig>,
Sourcepub fn set_or_clear_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<RecognitionConfig>,
pub fn set_or_clear_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<RecognitionConfig>,
Sourcepub fn set_config_mask<T>(self, v: T) -> Self
pub fn set_config_mask<T>(self, v: T) -> Self
Sets the value of config_mask.
Example
use wkt::FieldMask;
let x = BatchRecognizeRequest::new().set_config_mask(FieldMask::default()/* use setters */);Sourcepub fn set_or_clear_config_mask<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_config_mask<T>(self, v: Option<T>) -> Self
Sets or clears the value of config_mask.
Example
use wkt::FieldMask;
let x = BatchRecognizeRequest::new().set_or_clear_config_mask(Some(FieldMask::default()/* use setters */));
let x = BatchRecognizeRequest::new().set_or_clear_config_mask(None::<FieldMask>);Sourcepub fn set_recognition_output_config<T>(self, v: T) -> Selfwhere
T: Into<RecognitionOutputConfig>,
pub fn set_recognition_output_config<T>(self, v: T) -> Selfwhere
T: Into<RecognitionOutputConfig>,
Sets the value of recognition_output_config.
Example
use google_cloud_speech_v2::model::RecognitionOutputConfig;
let x = BatchRecognizeRequest::new().set_recognition_output_config(RecognitionOutputConfig::default()/* use setters */);Sourcepub fn set_or_clear_recognition_output_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<RecognitionOutputConfig>,
pub fn set_or_clear_recognition_output_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<RecognitionOutputConfig>,
Sets or clears the value of recognition_output_config.
Example
use google_cloud_speech_v2::model::RecognitionOutputConfig;
let x = BatchRecognizeRequest::new().set_or_clear_recognition_output_config(Some(RecognitionOutputConfig::default()/* use setters */));
let x = BatchRecognizeRequest::new().set_or_clear_recognition_output_config(None::<RecognitionOutputConfig>);Sourcepub fn set_processing_strategy<T: Into<ProcessingStrategy>>(self, v: T) -> Self
pub fn set_processing_strategy<T: Into<ProcessingStrategy>>(self, v: T) -> Self
Sets the value of processing_strategy.
Example
use google_cloud_speech_v2::model::batch_recognize_request::ProcessingStrategy;
let x0 = BatchRecognizeRequest::new().set_processing_strategy(ProcessingStrategy::DynamicBatching);Trait Implementations
Sourceimpl Clone for BatchRecognizeRequest
impl Clone for BatchRecognizeRequest
Sourcefn clone(&self) -> BatchRecognizeRequest
fn clone(&self) -> BatchRecognizeRequest
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for BatchRecognizeRequest
impl Debug for BatchRecognizeRequest
Sourceimpl Default for BatchRecognizeRequest
impl Default for BatchRecognizeRequest
Sourcefn default() -> BatchRecognizeRequest
fn default() -> BatchRecognizeRequest
Sourceimpl Message for BatchRecognizeRequest
impl Message for BatchRecognizeRequest
Sourceimpl PartialEq for BatchRecognizeRequest
impl PartialEq for BatchRecognizeRequest
impl StructuralPartialEq for BatchRecognizeRequest