#[non_exhaustive]pub struct Config {
pub name: String,
pub kms_key_name: String,
pub update_time: Option<Timestamp>,
/* private fields */
}Expand description
Message representing the config for the Speech-to-Text API. This includes an optional KMS key with which incoming data will be encrypted.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringOutput only. Identifier. The name of the config resource. There is exactly
one config resource per project per location. The expected format is
projects/{project}/locations/{location}/config.
kms_key_name: StringOptional. An optional KMS key
name that if
present, will be used to encrypt Speech-to-Text resources at-rest. Updating
this key will not encrypt existing resources using this key; only new
resources will be encrypted using this key. The expected format is
projects/{project}/locations/{location}/keyRings/{key_ring}/cryptoKeys/{crypto_key}.
update_time: Option<Timestamp>Output only. The most recent time this resource was modified.
Implementations
Sourceimpl Config
impl Config
Sourcepub fn set_kms_key_name<T: Into<String>>(self, v: T) -> Self
pub fn set_kms_key_name<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = Config::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = Config::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = Config::new().set_or_clear_update_time(None::<Timestamp>);Trait Implementations
impl StructuralPartialEq for Config