#[non_exhaustive]pub struct OperationMetadata {
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub resource: String,
pub method: String,
pub kms_key_name: String,
pub kms_key_version_name: String,
pub progress_percent: i32,
pub request: Option<Request>,
pub metadata: Option<Metadata>,
/* private fields */
}Expand description
Represents the metadata of a long-running operation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.create_time: Option<Timestamp>The time the operation was created.
update_time: Option<Timestamp>The time the operation was last updated.
resource: StringThe resource path for the target of the operation.
method: StringThe method that triggered the operation.
kms_key_name: StringThe KMS key
name with which
the content of the Operation is encrypted. The expected format is
projects/{project}/locations/{location}/keyRings/{key_ring}/cryptoKeys/{crypto_key}.
kms_key_version_name: StringThe KMS key version
name
with which content of the Operation is encrypted. The expected format is
projects/{project}/locations/{location}/keyRings/{key_ring}/cryptoKeys/{crypto_key}/cryptoKeyVersions/{crypto_key_version}.
progress_percent: i32The percent progress of the Operation. Values can range from 0-100. If the value is 100, then the operation is finished.
request: Option<Request>The request that spawned the Operation.
metadata: Option<Metadata>Specific metadata per RPC.
Implementations
Sourceimpl OperationMetadata
impl OperationMetadata
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = OperationMetadata::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = OperationMetadata::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = OperationMetadata::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = OperationMetadata::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = OperationMetadata::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = OperationMetadata::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_resource<T: Into<String>>(self, v: T) -> Self
pub fn set_resource<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_method<T: Into<String>>(self, v: T) -> Self
pub fn set_method<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_kms_key_name<T: Into<String>>(self, v: T) -> Self
pub fn set_kms_key_name<T: Into<String>>(self, v: T) -> Self
Sets the value of kms_key_name.
Example
let x = OperationMetadata::new().set_kms_key_name("example");Sourcepub fn set_kms_key_version_name<T: Into<String>>(self, v: T) -> Self
pub fn set_kms_key_version_name<T: Into<String>>(self, v: T) -> Self
Sets the value of kms_key_version_name.
Example
let x = OperationMetadata::new().set_kms_key_version_name("example");Sourcepub fn set_progress_percent<T: Into<i32>>(self, v: T) -> Self
pub fn set_progress_percent<T: Into<i32>>(self, v: T) -> Self
Sets the value of progress_percent.
Example
let x = OperationMetadata::new().set_progress_percent(42);Sourcepub fn set_request<T: Into<Option<Request>>>(self, v: T) -> Self
pub fn set_request<T: Into<Option<Request>>>(self, v: T) -> Self
Sets the value of request.
Note that all the setters affecting request are mutually
exclusive.
Example
use google_cloud_speech_v2::model::BatchRecognizeRequest;
let x = OperationMetadata::new().set_request(Some(
google_cloud_speech_v2::model::operation_metadata::Request::BatchRecognizeRequest(BatchRecognizeRequest::default().into())));Sourcepub fn batch_recognize_request(&self) -> Option<&Box<BatchRecognizeRequest>>
pub fn batch_recognize_request(&self) -> Option<&Box<BatchRecognizeRequest>>
The value of request
if it holds a BatchRecognizeRequest, None if the field is not set or
holds a different branch.
Sourcepub fn set_batch_recognize_request<T: Into<Box<BatchRecognizeRequest>>>(
self,
v: T,
) -> Self
pub fn set_batch_recognize_request<T: Into<Box<BatchRecognizeRequest>>>( self, v: T, ) -> Self
Sets the value of request
to hold a BatchRecognizeRequest.
Note that all the setters affecting request are
mutually exclusive.
Example
use google_cloud_speech_v2::model::BatchRecognizeRequest;
let x = OperationMetadata::new().set_batch_recognize_request(BatchRecognizeRequest::default()/* use setters */);
assert!(x.batch_recognize_request().is_some());
assert!(x.create_recognizer_request().is_none());
assert!(x.update_recognizer_request().is_none());
assert!(x.delete_recognizer_request().is_none());
assert!(x.undelete_recognizer_request().is_none());
assert!(x.create_custom_class_request().is_none());
assert!(x.update_custom_class_request().is_none());
assert!(x.delete_custom_class_request().is_none());
assert!(x.undelete_custom_class_request().is_none());
assert!(x.create_phrase_set_request().is_none());
assert!(x.update_phrase_set_request().is_none());
assert!(x.delete_phrase_set_request().is_none());
assert!(x.undelete_phrase_set_request().is_none());
assert!(x.update_config_request().is_none());Sourcepub fn create_recognizer_request(&self) -> Option<&Box<CreateRecognizerRequest>>
pub fn create_recognizer_request(&self) -> Option<&Box<CreateRecognizerRequest>>
The value of request
if it holds a CreateRecognizerRequest, None if the field is not set or
holds a different branch.
Sourcepub fn set_create_recognizer_request<T: Into<Box<CreateRecognizerRequest>>>(
self,
v: T,
) -> Self
pub fn set_create_recognizer_request<T: Into<Box<CreateRecognizerRequest>>>( self, v: T, ) -> Self
Sets the value of request
to hold a CreateRecognizerRequest.
Note that all the setters affecting request are
mutually exclusive.
Example
use google_cloud_speech_v2::model::CreateRecognizerRequest;
let x = OperationMetadata::new().set_create_recognizer_request(CreateRecognizerRequest::default()/* use setters */);
assert!(x.create_recognizer_request().is_some());
assert!(x.batch_recognize_request().is_none());
assert!(x.update_recognizer_request().is_none());
assert!(x.delete_recognizer_request().is_none());
assert!(x.undelete_recognizer_request().is_none());
assert!(x.create_custom_class_request().is_none());
assert!(x.update_custom_class_request().is_none());
assert!(x.delete_custom_class_request().is_none());
assert!(x.undelete_custom_class_request().is_none());
assert!(x.create_phrase_set_request().is_none());
assert!(x.update_phrase_set_request().is_none());
assert!(x.delete_phrase_set_request().is_none());
assert!(x.undelete_phrase_set_request().is_none());
assert!(x.update_config_request().is_none());Sourcepub fn update_recognizer_request(&self) -> Option<&Box<UpdateRecognizerRequest>>
pub fn update_recognizer_request(&self) -> Option<&Box<UpdateRecognizerRequest>>
The value of request
if it holds a UpdateRecognizerRequest, None if the field is not set or
holds a different branch.
Sourcepub fn set_update_recognizer_request<T: Into<Box<UpdateRecognizerRequest>>>(
self,
v: T,
) -> Self
pub fn set_update_recognizer_request<T: Into<Box<UpdateRecognizerRequest>>>( self, v: T, ) -> Self
Sets the value of request
to hold a UpdateRecognizerRequest.
Note that all the setters affecting request are
mutually exclusive.
Example
use google_cloud_speech_v2::model::UpdateRecognizerRequest;
let x = OperationMetadata::new().set_update_recognizer_request(UpdateRecognizerRequest::default()/* use setters */);
assert!(x.update_recognizer_request().is_some());
assert!(x.batch_recognize_request().is_none());
assert!(x.create_recognizer_request().is_none());
assert!(x.delete_recognizer_request().is_none());
assert!(x.undelete_recognizer_request().is_none());
assert!(x.create_custom_class_request().is_none());
assert!(x.update_custom_class_request().is_none());
assert!(x.delete_custom_class_request().is_none());
assert!(x.undelete_custom_class_request().is_none());
assert!(x.create_phrase_set_request().is_none());
assert!(x.update_phrase_set_request().is_none());
assert!(x.delete_phrase_set_request().is_none());
assert!(x.undelete_phrase_set_request().is_none());
assert!(x.update_config_request().is_none());Sourcepub fn delete_recognizer_request(&self) -> Option<&Box<DeleteRecognizerRequest>>
pub fn delete_recognizer_request(&self) -> Option<&Box<DeleteRecognizerRequest>>
The value of request
if it holds a DeleteRecognizerRequest, None if the field is not set or
holds a different branch.
Sourcepub fn set_delete_recognizer_request<T: Into<Box<DeleteRecognizerRequest>>>(
self,
v: T,
) -> Self
pub fn set_delete_recognizer_request<T: Into<Box<DeleteRecognizerRequest>>>( self, v: T, ) -> Self
Sets the value of request
to hold a DeleteRecognizerRequest.
Note that all the setters affecting request are
mutually exclusive.
Example
use google_cloud_speech_v2::model::DeleteRecognizerRequest;
let x = OperationMetadata::new().set_delete_recognizer_request(DeleteRecognizerRequest::default()/* use setters */);
assert!(x.delete_recognizer_request().is_some());
assert!(x.batch_recognize_request().is_none());
assert!(x.create_recognizer_request().is_none());
assert!(x.update_recognizer_request().is_none());
assert!(x.undelete_recognizer_request().is_none());
assert!(x.create_custom_class_request().is_none());
assert!(x.update_custom_class_request().is_none());
assert!(x.delete_custom_class_request().is_none());
assert!(x.undelete_custom_class_request().is_none());
assert!(x.create_phrase_set_request().is_none());
assert!(x.update_phrase_set_request().is_none());
assert!(x.delete_phrase_set_request().is_none());
assert!(x.undelete_phrase_set_request().is_none());
assert!(x.update_config_request().is_none());Sourcepub fn undelete_recognizer_request(
&self,
) -> Option<&Box<UndeleteRecognizerRequest>>
pub fn undelete_recognizer_request( &self, ) -> Option<&Box<UndeleteRecognizerRequest>>
The value of request
if it holds a UndeleteRecognizerRequest, None if the field is not set or
holds a different branch.
Sourcepub fn set_undelete_recognizer_request<T: Into<Box<UndeleteRecognizerRequest>>>(
self,
v: T,
) -> Self
pub fn set_undelete_recognizer_request<T: Into<Box<UndeleteRecognizerRequest>>>( self, v: T, ) -> Self
Sets the value of request
to hold a UndeleteRecognizerRequest.
Note that all the setters affecting request are
mutually exclusive.
Example
use google_cloud_speech_v2::model::UndeleteRecognizerRequest;
let x = OperationMetadata::new().set_undelete_recognizer_request(UndeleteRecognizerRequest::default()/* use setters */);
assert!(x.undelete_recognizer_request().is_some());
assert!(x.batch_recognize_request().is_none());
assert!(x.create_recognizer_request().is_none());
assert!(x.update_recognizer_request().is_none());
assert!(x.delete_recognizer_request().is_none());
assert!(x.create_custom_class_request().is_none());
assert!(x.update_custom_class_request().is_none());
assert!(x.delete_custom_class_request().is_none());
assert!(x.undelete_custom_class_request().is_none());
assert!(x.create_phrase_set_request().is_none());
assert!(x.update_phrase_set_request().is_none());
assert!(x.delete_phrase_set_request().is_none());
assert!(x.undelete_phrase_set_request().is_none());
assert!(x.update_config_request().is_none());Sourcepub fn create_custom_class_request(
&self,
) -> Option<&Box<CreateCustomClassRequest>>
pub fn create_custom_class_request( &self, ) -> Option<&Box<CreateCustomClassRequest>>
The value of request
if it holds a CreateCustomClassRequest, None if the field is not set or
holds a different branch.
Sourcepub fn set_create_custom_class_request<T: Into<Box<CreateCustomClassRequest>>>(
self,
v: T,
) -> Self
pub fn set_create_custom_class_request<T: Into<Box<CreateCustomClassRequest>>>( self, v: T, ) -> Self
Sets the value of request
to hold a CreateCustomClassRequest.
Note that all the setters affecting request are
mutually exclusive.
Example
use google_cloud_speech_v2::model::CreateCustomClassRequest;
let x = OperationMetadata::new().set_create_custom_class_request(CreateCustomClassRequest::default()/* use setters */);
assert!(x.create_custom_class_request().is_some());
assert!(x.batch_recognize_request().is_none());
assert!(x.create_recognizer_request().is_none());
assert!(x.update_recognizer_request().is_none());
assert!(x.delete_recognizer_request().is_none());
assert!(x.undelete_recognizer_request().is_none());
assert!(x.update_custom_class_request().is_none());
assert!(x.delete_custom_class_request().is_none());
assert!(x.undelete_custom_class_request().is_none());
assert!(x.create_phrase_set_request().is_none());
assert!(x.update_phrase_set_request().is_none());
assert!(x.delete_phrase_set_request().is_none());
assert!(x.undelete_phrase_set_request().is_none());
assert!(x.update_config_request().is_none());Sourcepub fn update_custom_class_request(
&self,
) -> Option<&Box<UpdateCustomClassRequest>>
pub fn update_custom_class_request( &self, ) -> Option<&Box<UpdateCustomClassRequest>>
The value of request
if it holds a UpdateCustomClassRequest, None if the field is not set or
holds a different branch.
Sourcepub fn set_update_custom_class_request<T: Into<Box<UpdateCustomClassRequest>>>(
self,
v: T,
) -> Self
pub fn set_update_custom_class_request<T: Into<Box<UpdateCustomClassRequest>>>( self, v: T, ) -> Self
Sets the value of request
to hold a UpdateCustomClassRequest.
Note that all the setters affecting request are
mutually exclusive.
Example
use google_cloud_speech_v2::model::UpdateCustomClassRequest;
let x = OperationMetadata::new().set_update_custom_class_request(UpdateCustomClassRequest::default()/* use setters */);
assert!(x.update_custom_class_request().is_some());
assert!(x.batch_recognize_request().is_none());
assert!(x.create_recognizer_request().is_none());
assert!(x.update_recognizer_request().is_none());
assert!(x.delete_recognizer_request().is_none());
assert!(x.undelete_recognizer_request().is_none());
assert!(x.create_custom_class_request().is_none());
assert!(x.delete_custom_class_request().is_none());
assert!(x.undelete_custom_class_request().is_none());
assert!(x.create_phrase_set_request().is_none());
assert!(x.update_phrase_set_request().is_none());
assert!(x.delete_phrase_set_request().is_none());
assert!(x.undelete_phrase_set_request().is_none());
assert!(x.update_config_request().is_none());Sourcepub fn delete_custom_class_request(
&self,
) -> Option<&Box<DeleteCustomClassRequest>>
pub fn delete_custom_class_request( &self, ) -> Option<&Box<DeleteCustomClassRequest>>
The value of request
if it holds a DeleteCustomClassRequest, None if the field is not set or
holds a different branch.
Sourcepub fn set_delete_custom_class_request<T: Into<Box<DeleteCustomClassRequest>>>(
self,
v: T,
) -> Self
pub fn set_delete_custom_class_request<T: Into<Box<DeleteCustomClassRequest>>>( self, v: T, ) -> Self
Sets the value of request
to hold a DeleteCustomClassRequest.
Note that all the setters affecting request are
mutually exclusive.
Example
use google_cloud_speech_v2::model::DeleteCustomClassRequest;
let x = OperationMetadata::new().set_delete_custom_class_request(DeleteCustomClassRequest::default()/* use setters */);
assert!(x.delete_custom_class_request().is_some());
assert!(x.batch_recognize_request().is_none());
assert!(x.create_recognizer_request().is_none());
assert!(x.update_recognizer_request().is_none());
assert!(x.delete_recognizer_request().is_none());
assert!(x.undelete_recognizer_request().is_none());
assert!(x.create_custom_class_request().is_none());
assert!(x.update_custom_class_request().is_none());
assert!(x.undelete_custom_class_request().is_none());
assert!(x.create_phrase_set_request().is_none());
assert!(x.update_phrase_set_request().is_none());
assert!(x.delete_phrase_set_request().is_none());
assert!(x.undelete_phrase_set_request().is_none());
assert!(x.update_config_request().is_none());Sourcepub fn undelete_custom_class_request(
&self,
) -> Option<&Box<UndeleteCustomClassRequest>>
pub fn undelete_custom_class_request( &self, ) -> Option<&Box<UndeleteCustomClassRequest>>
The value of request
if it holds a UndeleteCustomClassRequest, None if the field is not set or
holds a different branch.
Sourcepub fn set_undelete_custom_class_request<T: Into<Box<UndeleteCustomClassRequest>>>(
self,
v: T,
) -> Self
pub fn set_undelete_custom_class_request<T: Into<Box<UndeleteCustomClassRequest>>>( self, v: T, ) -> Self
Sets the value of request
to hold a UndeleteCustomClassRequest.
Note that all the setters affecting request are
mutually exclusive.
Example
use google_cloud_speech_v2::model::UndeleteCustomClassRequest;
let x = OperationMetadata::new().set_undelete_custom_class_request(UndeleteCustomClassRequest::default()/* use setters */);
assert!(x.undelete_custom_class_request().is_some());
assert!(x.batch_recognize_request().is_none());
assert!(x.create_recognizer_request().is_none());
assert!(x.update_recognizer_request().is_none());
assert!(x.delete_recognizer_request().is_none());
assert!(x.undelete_recognizer_request().is_none());
assert!(x.create_custom_class_request().is_none());
assert!(x.update_custom_class_request().is_none());
assert!(x.delete_custom_class_request().is_none());
assert!(x.create_phrase_set_request().is_none());
assert!(x.update_phrase_set_request().is_none());
assert!(x.delete_phrase_set_request().is_none());
assert!(x.undelete_phrase_set_request().is_none());
assert!(x.update_config_request().is_none());Sourcepub fn create_phrase_set_request(&self) -> Option<&Box<CreatePhraseSetRequest>>
pub fn create_phrase_set_request(&self) -> Option<&Box<CreatePhraseSetRequest>>
The value of request
if it holds a CreatePhraseSetRequest, None if the field is not set or
holds a different branch.
Sourcepub fn set_create_phrase_set_request<T: Into<Box<CreatePhraseSetRequest>>>(
self,
v: T,
) -> Self
pub fn set_create_phrase_set_request<T: Into<Box<CreatePhraseSetRequest>>>( self, v: T, ) -> Self
Sets the value of request
to hold a CreatePhraseSetRequest.
Note that all the setters affecting request are
mutually exclusive.
Example
use google_cloud_speech_v2::model::CreatePhraseSetRequest;
let x = OperationMetadata::new().set_create_phrase_set_request(CreatePhraseSetRequest::default()/* use setters */);
assert!(x.create_phrase_set_request().is_some());
assert!(x.batch_recognize_request().is_none());
assert!(x.create_recognizer_request().is_none());
assert!(x.update_recognizer_request().is_none());
assert!(x.delete_recognizer_request().is_none());
assert!(x.undelete_recognizer_request().is_none());
assert!(x.create_custom_class_request().is_none());
assert!(x.update_custom_class_request().is_none());
assert!(x.delete_custom_class_request().is_none());
assert!(x.undelete_custom_class_request().is_none());
assert!(x.update_phrase_set_request().is_none());
assert!(x.delete_phrase_set_request().is_none());
assert!(x.undelete_phrase_set_request().is_none());
assert!(x.update_config_request().is_none());Sourcepub fn update_phrase_set_request(&self) -> Option<&Box<UpdatePhraseSetRequest>>
pub fn update_phrase_set_request(&self) -> Option<&Box<UpdatePhraseSetRequest>>
The value of request
if it holds a UpdatePhraseSetRequest, None if the field is not set or
holds a different branch.
Sourcepub fn set_update_phrase_set_request<T: Into<Box<UpdatePhraseSetRequest>>>(
self,
v: T,
) -> Self
pub fn set_update_phrase_set_request<T: Into<Box<UpdatePhraseSetRequest>>>( self, v: T, ) -> Self
Sets the value of request
to hold a UpdatePhraseSetRequest.
Note that all the setters affecting request are
mutually exclusive.
Example
use google_cloud_speech_v2::model::UpdatePhraseSetRequest;
let x = OperationMetadata::new().set_update_phrase_set_request(UpdatePhraseSetRequest::default()/* use setters */);
assert!(x.update_phrase_set_request().is_some());
assert!(x.batch_recognize_request().is_none());
assert!(x.create_recognizer_request().is_none());
assert!(x.update_recognizer_request().is_none());
assert!(x.delete_recognizer_request().is_none());
assert!(x.undelete_recognizer_request().is_none());
assert!(x.create_custom_class_request().is_none());
assert!(x.update_custom_class_request().is_none());
assert!(x.delete_custom_class_request().is_none());
assert!(x.undelete_custom_class_request().is_none());
assert!(x.create_phrase_set_request().is_none());
assert!(x.delete_phrase_set_request().is_none());
assert!(x.undelete_phrase_set_request().is_none());
assert!(x.update_config_request().is_none());Sourcepub fn delete_phrase_set_request(&self) -> Option<&Box<DeletePhraseSetRequest>>
pub fn delete_phrase_set_request(&self) -> Option<&Box<DeletePhraseSetRequest>>
The value of request
if it holds a DeletePhraseSetRequest, None if the field is not set or
holds a different branch.
Sourcepub fn set_delete_phrase_set_request<T: Into<Box<DeletePhraseSetRequest>>>(
self,
v: T,
) -> Self
pub fn set_delete_phrase_set_request<T: Into<Box<DeletePhraseSetRequest>>>( self, v: T, ) -> Self
Sets the value of request
to hold a DeletePhraseSetRequest.
Note that all the setters affecting request are
mutually exclusive.
Example
use google_cloud_speech_v2::model::DeletePhraseSetRequest;
let x = OperationMetadata::new().set_delete_phrase_set_request(DeletePhraseSetRequest::default()/* use setters */);
assert!(x.delete_phrase_set_request().is_some());
assert!(x.batch_recognize_request().is_none());
assert!(x.create_recognizer_request().is_none());
assert!(x.update_recognizer_request().is_none());
assert!(x.delete_recognizer_request().is_none());
assert!(x.undelete_recognizer_request().is_none());
assert!(x.create_custom_class_request().is_none());
assert!(x.update_custom_class_request().is_none());
assert!(x.delete_custom_class_request().is_none());
assert!(x.undelete_custom_class_request().is_none());
assert!(x.create_phrase_set_request().is_none());
assert!(x.update_phrase_set_request().is_none());
assert!(x.undelete_phrase_set_request().is_none());
assert!(x.update_config_request().is_none());Sourcepub fn undelete_phrase_set_request(
&self,
) -> Option<&Box<UndeletePhraseSetRequest>>
pub fn undelete_phrase_set_request( &self, ) -> Option<&Box<UndeletePhraseSetRequest>>
The value of request
if it holds a UndeletePhraseSetRequest, None if the field is not set or
holds a different branch.
Sourcepub fn set_undelete_phrase_set_request<T: Into<Box<UndeletePhraseSetRequest>>>(
self,
v: T,
) -> Self
pub fn set_undelete_phrase_set_request<T: Into<Box<UndeletePhraseSetRequest>>>( self, v: T, ) -> Self
Sets the value of request
to hold a UndeletePhraseSetRequest.
Note that all the setters affecting request are
mutually exclusive.
Example
use google_cloud_speech_v2::model::UndeletePhraseSetRequest;
let x = OperationMetadata::new().set_undelete_phrase_set_request(UndeletePhraseSetRequest::default()/* use setters */);
assert!(x.undelete_phrase_set_request().is_some());
assert!(x.batch_recognize_request().is_none());
assert!(x.create_recognizer_request().is_none());
assert!(x.update_recognizer_request().is_none());
assert!(x.delete_recognizer_request().is_none());
assert!(x.undelete_recognizer_request().is_none());
assert!(x.create_custom_class_request().is_none());
assert!(x.update_custom_class_request().is_none());
assert!(x.delete_custom_class_request().is_none());
assert!(x.undelete_custom_class_request().is_none());
assert!(x.create_phrase_set_request().is_none());
assert!(x.update_phrase_set_request().is_none());
assert!(x.delete_phrase_set_request().is_none());
assert!(x.update_config_request().is_none());Sourcepub fn update_config_request(&self) -> Option<&Box<UpdateConfigRequest>>
👎Deprecated
pub fn update_config_request(&self) -> Option<&Box<UpdateConfigRequest>>
The value of request
if it holds a UpdateConfigRequest, None if the field is not set or
holds a different branch.
Sourcepub fn set_update_config_request<T: Into<Box<UpdateConfigRequest>>>(
self,
v: T,
) -> Self
👎Deprecated
pub fn set_update_config_request<T: Into<Box<UpdateConfigRequest>>>( self, v: T, ) -> Self
Sets the value of request
to hold a UpdateConfigRequest.
Note that all the setters affecting request are
mutually exclusive.
Example
use google_cloud_speech_v2::model::UpdateConfigRequest;
let x = OperationMetadata::new().set_update_config_request(UpdateConfigRequest::default()/* use setters */);
assert!(x.update_config_request().is_some());
assert!(x.batch_recognize_request().is_none());
assert!(x.create_recognizer_request().is_none());
assert!(x.update_recognizer_request().is_none());
assert!(x.delete_recognizer_request().is_none());
assert!(x.undelete_recognizer_request().is_none());
assert!(x.create_custom_class_request().is_none());
assert!(x.update_custom_class_request().is_none());
assert!(x.delete_custom_class_request().is_none());
assert!(x.undelete_custom_class_request().is_none());
assert!(x.create_phrase_set_request().is_none());
assert!(x.update_phrase_set_request().is_none());
assert!(x.delete_phrase_set_request().is_none());
assert!(x.undelete_phrase_set_request().is_none());Sourcepub fn set_metadata<T: Into<Option<Metadata>>>(self, v: T) -> Self
pub fn set_metadata<T: Into<Option<Metadata>>>(self, v: T) -> Self
Sets the value of metadata.
Note that all the setters affecting metadata are mutually
exclusive.
Example
use google_cloud_speech_v2::model::BatchRecognizeMetadata;
let x = OperationMetadata::new().set_metadata(Some(
google_cloud_speech_v2::model::operation_metadata::Metadata::BatchRecognizeMetadata(BatchRecognizeMetadata::default().into())));Sourcepub fn batch_recognize_metadata(&self) -> Option<&Box<BatchRecognizeMetadata>>
pub fn batch_recognize_metadata(&self) -> Option<&Box<BatchRecognizeMetadata>>
The value of metadata
if it holds a BatchRecognizeMetadata, None if the field is not set or
holds a different branch.
Sourcepub fn set_batch_recognize_metadata<T: Into<Box<BatchRecognizeMetadata>>>(
self,
v: T,
) -> Self
pub fn set_batch_recognize_metadata<T: Into<Box<BatchRecognizeMetadata>>>( self, v: T, ) -> Self
Sets the value of metadata
to hold a BatchRecognizeMetadata.
Note that all the setters affecting metadata are
mutually exclusive.
Example
use google_cloud_speech_v2::model::BatchRecognizeMetadata;
let x = OperationMetadata::new().set_batch_recognize_metadata(BatchRecognizeMetadata::default()/* use setters */);
assert!(x.batch_recognize_metadata().is_some());Trait Implementations
Sourceimpl Clone for OperationMetadata
impl Clone for OperationMetadata
Sourcefn clone(&self) -> OperationMetadata
fn clone(&self) -> OperationMetadata
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for OperationMetadata
impl Debug for OperationMetadata
Sourceimpl Default for OperationMetadata
impl Default for OperationMetadata
Sourcefn default() -> OperationMetadata
fn default() -> OperationMetadata
Sourceimpl Message for OperationMetadata
impl Message for OperationMetadata
Sourceimpl PartialEq for OperationMetadata
impl PartialEq for OperationMetadata
impl StructuralPartialEq for OperationMetadata