#[non_exhaustive]pub struct RecognitionOutputConfig {
pub output_format_config: Option<OutputFormatConfig>,
pub output: Option<Output>,
/* private fields */
}Expand description
Configuration options for the output(s) of recognition.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.output_format_config: Option<OutputFormatConfig>Optional. Configuration for the format of the results stored to output.
If unspecified transcripts will be written in the NATIVE format only.
output: Option<Output>Implementations
Sourceimpl RecognitionOutputConfig
impl RecognitionOutputConfig
Sourcepub fn set_output_format_config<T>(self, v: T) -> Selfwhere
T: Into<OutputFormatConfig>,
pub fn set_output_format_config<T>(self, v: T) -> Selfwhere
T: Into<OutputFormatConfig>,
Sets the value of output_format_config.
Example
use google_cloud_speech_v2::model::OutputFormatConfig;
let x = RecognitionOutputConfig::new().set_output_format_config(OutputFormatConfig::default()/* use setters */);Sourcepub fn set_or_clear_output_format_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<OutputFormatConfig>,
pub fn set_or_clear_output_format_config<T>(self, v: Option<T>) -> Selfwhere
T: Into<OutputFormatConfig>,
Sets or clears the value of output_format_config.
Example
use google_cloud_speech_v2::model::OutputFormatConfig;
let x = RecognitionOutputConfig::new().set_or_clear_output_format_config(Some(OutputFormatConfig::default()/* use setters */));
let x = RecognitionOutputConfig::new().set_or_clear_output_format_config(None::<OutputFormatConfig>);Sourcepub fn set_output<T: Into<Option<Output>>>(self, v: T) -> Self
pub fn set_output<T: Into<Option<Output>>>(self, v: T) -> Self
Sets the value of output.
Note that all the setters affecting output are mutually
exclusive.
Example
use google_cloud_speech_v2::model::GcsOutputConfig;
let x = RecognitionOutputConfig::new().set_output(Some(
google_cloud_speech_v2::model::recognition_output_config::Output::GcsOutputConfig(GcsOutputConfig::default().into())));Sourcepub fn gcs_output_config(&self) -> Option<&Box<GcsOutputConfig>>
pub fn gcs_output_config(&self) -> Option<&Box<GcsOutputConfig>>
The value of output
if it holds a GcsOutputConfig, None if the field is not set or
holds a different branch.
Sourcepub fn set_gcs_output_config<T: Into<Box<GcsOutputConfig>>>(self, v: T) -> Self
pub fn set_gcs_output_config<T: Into<Box<GcsOutputConfig>>>(self, v: T) -> Self
Sets the value of output
to hold a GcsOutputConfig.
Note that all the setters affecting output are
mutually exclusive.
Example
use google_cloud_speech_v2::model::GcsOutputConfig;
let x = RecognitionOutputConfig::new().set_gcs_output_config(GcsOutputConfig::default()/* use setters */);
assert!(x.gcs_output_config().is_some());
assert!(x.inline_response_config().is_none());Sourcepub fn inline_response_config(&self) -> Option<&Box<InlineOutputConfig>>
pub fn inline_response_config(&self) -> Option<&Box<InlineOutputConfig>>
The value of output
if it holds a InlineResponseConfig, None if the field is not set or
holds a different branch.
Sourcepub fn set_inline_response_config<T: Into<Box<InlineOutputConfig>>>(
self,
v: T,
) -> Self
pub fn set_inline_response_config<T: Into<Box<InlineOutputConfig>>>( self, v: T, ) -> Self
Sets the value of output
to hold a InlineResponseConfig.
Note that all the setters affecting output are
mutually exclusive.
Example
use google_cloud_speech_v2::model::InlineOutputConfig;
let x = RecognitionOutputConfig::new().set_inline_response_config(InlineOutputConfig::default()/* use setters */);
assert!(x.inline_response_config().is_some());
assert!(x.gcs_output_config().is_none());Trait Implementations
Sourceimpl Clone for RecognitionOutputConfig
impl Clone for RecognitionOutputConfig
Sourcefn clone(&self) -> RecognitionOutputConfig
fn clone(&self) -> RecognitionOutputConfig
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for RecognitionOutputConfig
impl Debug for RecognitionOutputConfig
Sourceimpl Default for RecognitionOutputConfig
impl Default for RecognitionOutputConfig
Sourcefn default() -> RecognitionOutputConfig
fn default() -> RecognitionOutputConfig
Sourceimpl Message for RecognitionOutputConfig
impl Message for RecognitionOutputConfig
Sourceimpl PartialEq for RecognitionOutputConfig
impl PartialEq for RecognitionOutputConfig
impl StructuralPartialEq for RecognitionOutputConfig