TranscriptNormalization

Struct TranscriptNormalization 

#[non_exhaustive]
pub struct TranscriptNormalization { pub entries: Vec<Entry>, /* private fields */ }
Transcription normalization configuration. Use transcription normalization to automatically replace parts of the transcript with phrases of your choosing. For StreamingRecognize, this normalization only applies to stable partial transcripts (stability > 0.8) and final transcripts.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
entries: Vec<Entry>

A list of replacement entries. We will perform replacement with one entry at a time. For example, the second entry in [“cat” => “dog”, “mountain cat” => “mountain dog”] will never be applied because we will always process the first entry before it. At most 100 entries.

Implementations

Source

impl TranscriptNormalization

pub fn new() -> Self

Creates a new default instance.

pub fn set_entries<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<Entry>,

Sets the value of entries.

Example
use google_cloud_speech_v2::model::transcript_normalization::Entry;
let x = TranscriptNormalization::new()
    .set_entries([
        Entry::default()/* use setters */,
        Entry::default()/* use (different) setters */,
    ]);