#[non_exhaustive]pub struct UndeletePhraseSetRequest {
pub name: String,
pub validate_only: bool,
pub etag: String,
/* private fields */
}Expand description
Request message for the UndeletePhraseSet method.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. The name of the PhraseSet to undelete.
Format: projects/{project}/locations/{location}/phraseSets/{phrase_set}
validate_only: boolIf set, validate the request and preview the undeleted PhraseSet, but do not actually undelete it.
etag: StringThis checksum is computed by the server based on the value of other fields. This may be sent on update, undelete, and delete requests to ensure the client has an up-to-date value before proceeding.
Implementations